@@ -3,11 +3,13 @@ from .base import *
 class BOM(Object):
     endpoint="/items/{guid}/bom"
 
-    @cachedproperty
+    @property
+    @lazy
     def settings(self):
         return self._client.get(f"/items{self.guid}/bom/settings")
 
-    @cachedproperty
+    @property
+    @lazy
     def lines(self):
 
         lines=[self._client.BOMLine(**dataset) for dataset in self.results]
@@ -17,10 +19,12 @@ class BOM(Object):
 
 class BOMLine(Object):
 
-    @cachedproperty
+    @property
+    @lazy
     def endpoint(self):
         return f"/items/{self.bom.guid}/bom/{self.guid}"
     
-    @cachedproperty
+    @property
+    @lazy
     def item(self):
         return self._client.Item(self.__dict__["item"]["guid"])
\ No newline at end of file
